@@ -133,6 +133,28 @@ def accuracy_score(obser_df, power, polynomial_degree, search_radious):
 
 
 
+def show_map(input_raster='', input_point_shapefile='', height=8, width=7, colormap='nipy_spectral'):
+    image_data = rasterio.open(input_raster)
+    pointShp = gpd.read_file(input_point_shapefile)
+    
+    my_matrix = image_data.read(1)
+    my_matrix = np.ma.masked_where(my_matrix==32767, my_matrix)
+    fig, ax =plt.subplots()
+    image_hidden = ax.imshow(my_matrix, cmap=colormap)
+    plt.close()
+
+    fig, ax = plt.subplots(figsize=(width, height))
+    image = show(image_data, cmap=colormap, ax=ax)
+    pointShp.plot(ax=ax, marker='D')
+    fig.colorbar(image_hidden, ax=ax)
+    plt.show()
+
+
+######################
+
+
+
+
 def regression_idw_interpolation(input_point_shapefile='',
                                  input_raster_file='',
                                  extent_shapefile='',
@@ -153,7 +175,7 @@ def regression_idw_interpolation(input_point_shapefile='',
 
     # obser_df stands for observation_dataframe, lat, lon, elevation, data_value for each station will be stored here.
     obser_df = pd.DataFrame()
-    obser_df['station_name'] = metStat.StationNam
+    obser_df['station_name'] = metStat.iloc[:, 0]
 
     # create two list of indexes of station longitude, latitude in elevation raster file.
     lons, lats = re_elevation.index([lon for lon in metStat.geometry.x], [lat for lat in metStat.geometry.y])
@@ -187,10 +209,12 @@ def regression_idw_interpolation(input_point_shapefile='',
     with rasterio.open(output_filename, 'w', **re_elevation.meta) as reg_idw:
         reg_idw.write(regression_idw_array, 1)
         
-    fig, ax = plt.subplots(figsize=(6,8))
-    show(rasterio.open(output_filename), cmap='nipy_spectral', ax=ax)
-    metStat.plot(ax=ax, marker='D')
-    plt.show()
+    show_map(output_filename, input_point_shapefile)
+        
+#     fig, ax = plt.subplots(figsize=(6,8))
+#     show(rasterio.open(output_filename), cmap='nipy_spectral', ax=ax)
+#     metStat.plot(ax=ax, marker='D')
+#     plt.show()
     
     accuracy_score(obser_df, power, polynomial_degree, search_radious)
     print('RMSE:', mean_squared_error(obser_df.data_value.to_list(), obser_df.predicted.to_list(), squared=False))
